@@ -835,12 +835,7 @@ class Graphics(Handler):
         return self.nextPC()
 
     # Initialize the graphics environment
-    def k_init(self, command):
-        # return True
-        if self.nextIs('graphics'):
-            self.add(command)
-            return True
-        return False
+    # Unused: def k_init(self, command):
     
     def r_init(self, command):
         self.app = QApplication(sys.argv)
